@@ -6,7 +6,7 @@
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
-BEGIN { $| = 1; print "1..60\n"; }
+BEGIN { $| = 1; print "1..62\n"; }
 END {print "not ok 1\n" unless $loaded;}
 use Data::Table;
 #use Data::Dumper;
@@ -440,6 +440,20 @@ if (equal($t_unix->rowRefs, $t_unix_noheader->rowRefs) &&
   print "not ok 58 using fromFile\n";
 }
 
+$t=Data::Table::fromFile("ttt.tsv", {transform_element=>0});
+$t2=Data::Table::fromFile("ttt.csv");
+if (equal($t->rowRefs(), $t2->rowRefs())) {
+  print "ok 59 using fromFile, fromTSV, transform_element\n";
+} else {
+  print "not ok 59 using fromFile, fromTSV, transform_element\n";
+}
+
+if ($t->html({odd=>'myOdd', even=>'myEven', header=>'myHeader'})) {
+  print "ok 60 using html with CSS class\n";
+} else {
+  print "not ok 60 using html with CSS\n";
+}
+
 # use DBI;
 # $dbh= DBI->connect("DBI:mysql:test", "test", "") or die $dbh->errstr;
 # $t = Data::Table::fromSQL($dbh, "show tables");
@@ -456,15 +470,15 @@ package main;
 
 $foo=FOO->new([[11,12],[21,22],[31,32]],['header1','header2'],0);
 if ($foo->csv) {
-  print "ok 59 Inheritance\n";
+  print "ok 61 Inheritance\n";
 } else {
-  print "not ok 59 Inheritance\n";
+  print "not ok 61 Inheritance\n";
 }
 $foo = FOO->fromCSVi("aaa.csv");
 if ($foo->csv) {
-  print "ok 60 inheritated instant method fromCSVi\n";
+  print "ok 62 inheritated instant method fromCSVi\n";
 } else {
-  print "not ok 60 inheritated instant method fromCSVi\n";
+  print "not ok 62 inheritated instant method fromCSVi\n";
 }
 
 sub equal {
